@@ -105,8 +105,8 @@ sub _parse {
 
 	my $lyricID = 0; my $lyricChecksum = 0;
 	for (my $i=0;$i<$#{$xmldoc->{'SearchLyricResult'}};$i++) {
-		if ($xmldoc->{'SearchLyricResult'}->[$i]->{'Artist'} =~ /^$artist_in$/i
-				&& $xmldoc->{'SearchLyricResult'}->[$i]->{'Song'} =~ /^$song_in/i
+		if ($xmldoc->{'SearchLyricResult'}->[$i]->{'Artist'} =~ /^\Q$artist_in\E$/i
+				&& $xmldoc->{'SearchLyricResult'}->[$i]->{'Song'} =~ /^\Q$song_in\E/i
 				&& $xmldoc->{'SearchLyricResult'}->[$i]->{'LyricId'}
 				&& $xmldoc->{'SearchLyricResult'}->[$i]->{'LyricChecksum'}) {
 			$lyricID = $xmldoc->{'SearchLyricResult'}->[$i]->{'LyricId'};
@@ -117,8 +117,8 @@ sub _parse {
 	}
 	unless ($lyricID && $lyricChecksum) {
 		for (my $i=0;$i<$#{$xmldoc->{'SearchLyricResult'}};$i++) {
-			if ($xmldoc->{'SearchLyricResult'}->[$i]->{'Artist'} =~ /$artist_in/i
-					&& $xmldoc->{'SearchLyricResult'}->[$i]->{'Song'} =~ /^$song_in/i
+			if ($xmldoc->{'SearchLyricResult'}->[$i]->{'Artist'} =~ /\Q$artist_in\E/i
+					&& $xmldoc->{'SearchLyricResult'}->[$i]->{'Song'} =~ /^\Q$song_in\E/i
 					&& $xmldoc->{'SearchLyricResult'}->[$i]->{'LyricId'}
 					&& $xmldoc->{'SearchLyricResult'}->[$i]->{'LyricChecksum'}) {
 				$lyricID = $xmldoc->{'SearchLyricResult'}->[$i]->{'LyricId'};
@@ -129,7 +129,7 @@ sub _parse {
 		}
 	}
 	unless ($lyricID && $lyricChecksum) {
-		carp($self->{'Error'} = "e:$Source - No entries matched (artist=$artist_in, title=$song_in.");
+		$self->{'Error'} = "..$Source - Lyrics not found.";
 		return '';
 	}
 
@@ -163,10 +163,10 @@ sub _parse {
 	} else {
 		my $Source = $self->{'Source'};
 		if ($res->status_line =~ /^404/) {
-			$self->{'Error'} = "..$Source - Lyrics not found (Server Error 404).";
+			$self->{'Error'} = "..$Source - Lyrics not found.";
 		} else {
-			carp($self->{'Error'} = "e:$Source - Failed to retrieve ".$self->{'Url'}
-					.' ('.$res->status_line.').');
+			carp($self->{'Error'} = "e:$Source - Failed to retrieve $songUrl ("
+					.$res->status_line.').');
 		}
 		return '';
 	}
@@ -259,7 +259,7 @@ pass to chartlyrics.com.  Some sites are pickey about receiving a user-agent
 string that corresponds to a valid / supported web-browser to prevent their 
 sites from being "scraped" by programs, such as this.  
 
-Default:  I<"Mozilla/5.0 (X11; Linux x86_64; rv:84.0) Gecko/20100101 Firefox/84.0">.
+Default:  I<"Mozilla/5.0 (X11; Linux x86_64; rv:112.0) Gecko/20100101 Firefox/112.0">.
 
 NOTE:  This value will be overridden if $founder->agent("agent") is 
 called!
@@ -309,7 +309,7 @@ Some sites are pickey about receiving a user-agent
 string that corresponds to a valid / supported web-browser to prevent their 
 sites from being "scraped" by programs, such as this.  
 
-Default:  I<"Mozilla/5.0 (X11; Linux x86_64; rv:80.0) Gecko/20100101 Firefox/80.0">
+Default:  I<"Mozilla/5.0 (X11; Linux x86_64; rv:112.0) Gecko/20100101 Firefox/112.0">
 
 If no argument is passed, it returns the current GENERAL user-agent string in 
 effect (but a different agent option is specified for a specific module may 
